@@ -1,20 +1,9 @@
-#!D:\bld\gnuradio_1611300590120\_h_env\python.exe
+#!D:\bld\gnuradio_1632426943199\_h_env\python.exe
 # Copyright 2016 Free Software Foundation, Inc.
 # This file is part of GNU Radio
 #
-# GNU Radio Companion is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
-# GNU Radio Companion is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 import os
 import sys
@@ -23,13 +12,14 @@ import sys
 GR_IMPORT_ERROR_MESSAGE = """\
 Cannot import gnuradio.
 
-Is the model path environment variable set correctly?
+Is the Python path environment variable set correctly?
     All OS: PYTHONPATH
 
 Is the library path environment variable set correctly?
     Linux: LD_LIBRARY_PATH
     Windows: PATH
-    MacOSX: DYLD_LIBRARY_PATH
+
+See https://wiki.gnuradio.org/index.php/ModuleNotFoundError
 """
 
 
